pub struct LoadedPlaybook {
pub binary: ModuleBinary,
pub configurations: HashMap<String, Option<Value>>,
pub paths: HashMap<String, PathBuf>,
}Expand description
A loaded playbook where all the libraries are on disk and the binary is loaded
Fields
binary: ModuleBinaryconfigurations: HashMap<String, Option<Value>>Per-class capability configuration. Keys are class names.
paths: HashMap<String, PathBuf>Trait Implementations
Sourceimpl Clone for LoadedPlaybook
impl Clone for LoadedPlaybook
Sourcefn clone(&self) -> LoadedPlaybook
fn clone(&self) -> LoadedPlaybook
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadedPlaybook
impl Debug for LoadedPlaybook
Sourceimpl<'de> Deserialize<'de> for LoadedPlaybook
impl<'de> Deserialize<'de> for LoadedPlaybook
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LoadedPlaybook
impl PartialEq for LoadedPlaybook
Sourcefn eq(&self, other: &LoadedPlaybook) -> bool
fn eq(&self, other: &LoadedPlaybook) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LoadedPlaybook
impl Serialize for LoadedPlaybook
impl StructuralPartialEq for LoadedPlaybook