Environment

Struct Environment 

pub struct Environment {
    pub root: PathBuf,
    pub target_dir: PathBuf,
    pub manifest: ProjectManifest,
    pub cache_manager: Arc<CacheManager>,
}
Central context to manage cargo compilation environment

Fields

root: PathBuftarget_dir: PathBufmanifest: ProjectManifestcache_manager: Arc<CacheManager>

Implementations

Source

impl Environment

pub async fn new( root: PathBuf, cache_manager: Arc<CacheManager>, ) -> EnvResult<Self>

Create a new Environment by fetching metadata and detecting manifests from the given root

pub fn package(&self) -> String

pub fn version(&self) -> String

pub fn author(&self) -> String

pub async fn get_target_dir(path: &Path) -> EnvResult<PathBuf>

Run cargo metadata to find the target directory

pub async fn generate_lockfile(&self) -> EnvResult<String>

pub async fn compile(&self, extra_args: &[&str], capture: bool) -> EnvResult<()>

Compile the project (defaults to release)

pub fn get_wasm_artifact(&self, name: &str) -> EnvResult<PathBuf>

Get path to the compiled wasm artifact

pub async fn get_library_artifact(&self, name: &str) -> EnvResult<CapBinary>

Get path to the compiled library artifact (dylib/so/dll)

pub async fn load_artifacts_from_target( &self, target_dir: &Path, ) -> EnvResult<Vec<Artifacts>>

Load artifacts from an existing target directory without compiling

pub async fn pack(&self, capture: bool) -> EnvResult<Vec<Artifacts>>

pub async fn expand_debug(&self) -> EnvResult<()>

pub async fn capability_spec(&self) -> EnvResult<InterfaceSpec<'static>>

pub async fn playbook_spec(&self) -> EnvResult<PlaybookSpec>